@@ -123,7 +123,9 @@ GeomNFLwordmark <- ggplot2::ggproto(
   draw_panel = function(data, panel_params, coord, na.rm = FALSE) {
     data <- coord$transform(data, panel_params)
 
-    data$team_abbr <- nflreadr::clean_team_abbrs(as.character(data$team_abbr), keep_non_matches = FALSE)
+    data$team_abbr <- suppressWarnings(
+      nflreadr::clean_team_abbrs(as.character(data$team_abbr), keep_non_matches = TRUE)
+    )
 
     grobs <- lapply(seq_along(data$team_abbr), build_grobs, alpha = data$alpha, colour = data$colour, data = data, type = "wordmarks")
 
